using BPA.SAAS.Manage.Application.DataBase.Dtos.GoodsTechnology;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.DataBase.Interface
{
    public interface IGoodsTechnologyService
    {
        Task<bool> UpdateGoodsTechnologyAction(List<GoodsTechnologyActionBaseDto> inputDto);
        Task<bool> AddGoodsTechnologyAction(List<GoodsTechnologyActionBaseDto> inputDto);
        Task<List<GoodsTechnologyActionListView>> GetGoodsTechnologyAction(string goodsId);
        Task<bool> DeleteGoodsTechnologyAction(string id);
        Task<bool> DeleteGoodsTechnologyAction(GoodsTechnologDelete dto);
        Task<List<DeviceGoodsTechnologyView>> GetDeviceTechnology();
    }
}
